function rez = calcGaussian (sigma, siz, derivation)
    if nargin < 3 
        rez = calcG (sigma, siz);
    else
        rez = calcDG (sigma, siz, derivation);
    end
end

function rez = calcG (sigma, siz)
    rez = zeros (siz);
    cent = (siz-1)/2;
    
    [x, y] = meshgrid (-cent:cent, -cent:cent);
    
    rez = exp (-(x.^2 + y.^2)/(2*sigma^2));
    rez = rez/sum (sum (rez));
end

function rez = calcDG (sigma, siz, derivation)
    rez = zeros (siz);
    cent = (siz-1)/2;
    o = sigma;
    
    [x, y] = meshgrid (-cent:cent, -cent:cent);
    
    EX = exp (-(x.^2 + y.^2)/(2*sigma^2));   
    
    switch derivation
        case 'x'
            rez = -x.*EX/(2*o^4*pi);
        case 'y'
            rez = -y.*EX/(2*o^4*pi);
        case 'xx'
            rez = (x.^2).*EX/(2*o^6*pi) - EX/(2*o^4*pi);
        case 'yy'
            rez = (y.^2).*EX/(2*o^6*pi) - EX/(2*o^4*pi);
        case 'xy'
            rez = (x.*y).*EX/(2*o^6*pi);
    end
end