function ret = calcH (src, dst, siz)
    % from src to dst
    % src - source points
    % dst - destination points
    % image size (for normalisation)
    
    % check the parameters
    if nargin ==1
        src = dst (:, 3:4);
        dst = dst (:, 1:2);
    end

    if nargin < 3
        siz = 0;
    end
    
    if size (dst, 2)<3
        dst (:, 3) = 1;
    end

    if size (src, 2)<3
        src (:, 3) = 1;
    end
    
    if siz
        % normalising transformation
        T = [(2 / siz (1)), 0, -1; 0, (2 / siz (2)), -1; 0, 0, 1];
    
        % apply the transformation
        dst = (T * (dst'))';
    end
    
	A = [];
    % create system of linear equations
    for i=1:size (dst, 1)
        x = src (i, :);
        X = dst (i, 1);
        Y = dst (i, 2);
        W = dst (i, 3);
        
        A (end+1,:)=[ 0, 0, 0, -W*x, Y*x];
        A (end+1,:)=[ W*x, 0, 0, 0, -X*x];
    end

    % solve the system
	[u, d, v] = svd (A);
	h = v (:,9);

	H(1,:) = h(1:3);
	H(2,:) = h(4:6);
	H(3,:) = h(7:9);
    
    if siz
        % undo the transformation
        H = (T)^-1*H;
    	H = H/abs(sum(sum(H)));
    end
    ret = H;
end
